@@ -21,11 +21,11 @@
  *****************************************************************************/
 
 #include <KAboutData>
-#include <KCmdLineArgs>
-#include <KUniqueApplication>
-#include <KXmlGuiWindow>
-
-#include <QtDBus>
+#include <KLocalizedString>
+#include <Kdelibs4ConfigMigrator>
+#include <QApplication>
+#include <QCommandLineParser>
+#include <QDBusConnection>
 
 #include "kiten.h"
 
@@ -38,29 +38,37 @@ int main( int argc, char *argv[] )
 //   qInstallMsgHandler(noMessageOutput);	//Disable Qt Errors from showing
 
   // Copyright and author information
-  KAboutData aboutData( "kiten", 0, ki18n("Kiten"), "1.3", ki18n("Japanese Reference Tool"),
-                  KAboutData::License_GPL_V2, ki18n("(c) 2001-2004, Jason Katz-Brown\n"
+  Kdelibs4ConfigMigrator migrate(QLatin1String("kiten"));
+  migrate.setConfigFiles(QStringList() << QLatin1String("kitenrc"));
+  migrate.setUiFiles(QStringList() << QLatin1String("kitenui.rc"));
+  migrate.migrate();
+
+  KAboutData aboutData( QStringLiteral("kiten"), i18n("Kiten"), QStringLiteral("1.3"), i18n("Japanese Reference Tool"),
+                  KAboutLicense::GPL_V2, i18n("(c) 2001-2004, Jason Katz-Brown\n"
                                                     "(c) 2006-2007, Eric Kjeldergaard\n"
                                                     "(c) 2006-2008, Joseph Kerian\n"
                                                     "(c) 2011, Daniel E. Moctezuma"),
-                  KLocalizedString(), "http://edu.kde.org/kiten" );
+                  QString(), "http://edu.kde.org/kiten" );
 
-  aboutData.addAuthor( ki18n("Jason Katz-Brown"), ki18n("Original author"), "jason@katzbrown.com" );
-  aboutData.addCredit( ki18n("Jim Breen"),        ki18n("Wrote xjdic, of which Kiten borrows code, and the xjdic index file generator.\nAlso is main author of edict and kanjidic, which Kiten essentially require."), "jwb@csse.monash.edu.au" );
-  aboutData.addAuthor( ki18n("Neil Stevens"),     ki18n("Code simplification, UI suggestions."), "neil@qualityassistant.com" );
-  aboutData.addCredit( ki18n("David Vignoni"),    ki18n("svg icon"), "david80v@tin.it");
-  aboutData.addCredit( ki18n("Paul Temple"),      ki18n("Porting to KConfig XT, bug fixing"), "paul.temple@gmx.net" );
-  aboutData.addAuthor( ki18n("Joseph Kerian"),    ki18n("KDE4 rewrite"), "jkerian@gmail.com" );
-  aboutData.addAuthor( ki18n("Eric Kjeldergaard"), ki18n("KDE4 rewrite"), "kjelderg@gmail.com" );
-  aboutData.addAuthor( ki18n("Daniel E. Moctezuma"), ki18n("Deinflection system improvements, Dictionary updates for EDICT and KANJIDIC, GUI Improvements, Kanji Browser, Bug fixes, Code polishing and simplification"), "democtezuma@gmail.com" );
+  aboutData.addAuthor( i18n("Jason Katz-Brown"), i18n("Original author"), "jason@katzbrown.com" );
+  aboutData.addCredit( i18n("Jim Breen"),        i18n("Wrote xjdic, of which Kiten borrows code, and the xjdic index file generator.\nAlso is main author of edict and kanjidic, which Kiten essentially require."), "jwb@csse.monash.edu.au" );
+  aboutData.addAuthor( i18n("Neil Stevens"),     i18n("Code simplification, UI suggestions."), "neil@qualityassistant.com" );
+  aboutData.addCredit( i18n("David Vignoni"),    i18n("svg icon"), "david80v@tin.it");
+  aboutData.addCredit( i18n("Paul Temple"),      i18n("Porting to KConfig XT, bug fixing"), "paul.temple@gmx.net" );
+  aboutData.addAuthor( i18n("Joseph Kerian"),    i18n("KDE4 rewrite"), "jkerian@gmail.com" );
+  aboutData.addAuthor( i18n("Eric Kjeldergaard"), i18n("KDE4 rewrite"), "kjelderg@gmail.com" );
+  aboutData.addAuthor( i18n("Daniel E. Moctezuma"), i18n("Deinflection system improvements, Dictionary updates for EDICT and KANJIDIC, GUI Improvements, Kanji Browser, Bug fixes, Code polishing and simplification"), "democtezuma@gmail.com" );
 
   aboutData.setOrganizationDomain( "kde.org" ); //Set this for the DBUS ID
-  KCmdLineArgs::init( argc, argv, &aboutData );
+  QApplication app(argc, argv);
+  QCommandLineParser parser;
+  KAboutData::setApplicationData(aboutData);
 
-  KCmdLineOptions options;
-  KCmdLineArgs::addCmdLineOptions( options ); // Add our own options.
-
-  KUniqueApplication app;
+  parser.addVersionOption();
+  parser.addHelpOption();
+  aboutData.setupCommandLine(&parser);
+  parser.process(app);
+  aboutData.processCommandLine(&parser);
 
   Kiten *kiten = new Kiten();
 
